/*
 * Copyright 2007 Etienne Studer
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nu.studer.idea.notifier;

import java.util.Comparator;

import com.intellij.ide.plugins.IdeaPluginDescriptor;

/**
 * This class compares <code>PluginRepositoryQueryResult</code>s using the 'name' attribute of the current plugin descriptors.
 *
 * @author <a href="mailto:intellij@studer.nu">Etienne Studer</a>, Nov 14, 2006
 * @see PluginRepositoryManager.PluginRepositoryQueryResult
 * @see IdeaPluginDescriptor
 */
public class PluginRepositoryQueryResultComparator implements Comparator<PluginRepositoryManager.PluginRepositoryQueryResult> {
    public int compare(PluginRepositoryManager.PluginRepositoryQueryResult inA, PluginRepositoryManager.PluginRepositoryQueryResult inB) {
        String nameA = inA.getCurrentDescriptor().getName();
        if (nameA == null) {
            nameA = "";
        }

        String nameB = inB.getCurrentDescriptor().getName();
        if (nameB == null) {
            nameB = "";
        }

        return nameA.compareToIgnoreCase(nameB);
    }
}
